@@ -14,7 +14,7 @@
     limitations under the License.
 
 """
-__version__ = '3.1.1'
+__version__ = '3.2.0'
 
 
 from pytool import (
@@ -22,5 +22,16 @@ from pytool import (
         json,
         lang,
         proxy,
+        text,
         time,
         )
+
+__all__ = [
+        'cmd',
+        'json',
+        'lang',
+        'proxy',
+        'text',
+        'time',
+        ]
+
