@@ -8,6 +8,7 @@ import sys
 import signal
 import argparse
 
+import pytool.text
 try:
     import pyconfig
 except ImportError:
@@ -140,6 +141,37 @@ class Command(object):
         """
         raise NotImplementedError("'run' is not implemented")
 
+    def describe(self, description):
+        """
+        Describe the command in more detail. This will be displayed in addition
+        to the argument help.
+
+        This automatically strips leading indentation but does not strip all
+        formatting like the ``ArgumentParser(description='')`` keyword.
+
+        **Example**::
+
+            class MyCommand(Command):
+                def set_opts(self):
+                    self.describe(\"\"\"
+                        This is an example command. To use the example command,
+                        run it.\"\"\")
+
+                def run(self):
+                    pass
+
+
+        """
+        # This has to be called from within set_opts(), when the parser exists
+        if not self.parser:
+            return
+
+        description = pytool.text.wrap(description, indent='    ')
+        # Update the parser object with the new description
+        self.parser.description = description
+        # And use the raw class so it doesn't strip our formatting
+        self.parser.formatter_class = argparse.RawDescriptionHelpFormatter
+
     @classmethod
     def console_script(cls):
         """ Method used to start the command when launched from a distutils
