@@ -3,7 +3,7 @@ import sys
 import mock
 
 import pytool
-from .util import *
+from .util import eq_, raises
 
 
 class TestCommand(pytool.cmd.Command):
@@ -47,3 +47,4 @@ def test_console_script(start):
     TestCommand().console_script()
     start.assert_called_with(sys.argv[1:])
 
+
